@@ -4,6 +4,7 @@ import json
 import os
 from itertools import chain
 from pathlib import Path
+from typing import List
 
 import markdown
 import requests
@@ -412,12 +413,12 @@ class DiffStix(object):
                 # find changes, revocations and deprecations
                 for key in intersection:
 
-                    # find revoked objects
+                    # find revoked objects in the new bundle
                     if (
                         "revoked" in new["id_to_obj"][key]
                         and new["id_to_obj"][key]["revoked"]
                     ):
-                        # if it was previously revoked, it's not a change
+                        # only work with newly revoked objects
                         if (
                             not "revoked" in old["id_to_obj"][key]
                             or not old["id_to_obj"][key]["revoked"]
@@ -438,6 +439,10 @@ class DiffStix(object):
                             else:
                                 revoked_by_key = revoked_by_key[0]["target_ref"]
 
+                            if revoked_by_key not in new["id_to_obj"]:
+                                logger.error(f"{key} revoked by {revoked_by_key}, but {revoked_by_key} not found in new STIX bundle!!")
+                                continue
+
                             new["id_to_obj"][key]["revoked_by"] = new["id_to_obj"][
                                 revoked_by_key
                             ]
@@ -1257,8 +1262,8 @@ def get_parsed_args():
 
 # Used by attack-website script to generate changelog
 def get_new_changelog_md(
-    domains: list[str] = ["enterprise-attack", "mobile-attack"],
-    layers: list[str] = layer_defaults,
+    domains: List[str] = ["enterprise-attack", "mobile-attack"],
+    layers: List[str] = layer_defaults,
     markdown_file: str = md_default,
     minor_changes: bool = False,
     unchanged: bool = False,
@@ -1266,7 +1271,7 @@ def get_new_changelog_md(
     old: str = None,
     show_key: bool = False,
     site_prefix: str = "",
-    types: list[str] = ["technique", "software", "group", "mitigation", "datasource"],
+    types: List[str] = ["technique", "software", "group", "mitigation", "datasource"],
     use_taxii: bool = False,
     use_mitre_cti: bool = False,
     verbose: bool = False,
